@@ -17,6 +17,8 @@ from quickbuild.endpoints import (
     Issues,
     Measurements,
     Memberships,
+    Nodes,
+    Reports,
     Requests,
     Resources,
     Shares,
@@ -57,6 +59,8 @@ class QuickBuild:
         self.issues = Issues(self)
         self.measurements = Measurements(self)
         self.memberships = Memberships(self)
+        self.nodes = Nodes(self)
+        self.reports = Reports(self)
         self.requests = Requests(self)
         self.resources = Resources(self)
         self.shares = Shares(self)
