@@ -9,6 +9,8 @@ from .identifiers import Identifiers
 from .issues import Issues
 from .measurements import Measurements
 from .memberships import Memberships
+from .nodes import Nodes
+from .reports import Reports
 from .requests import Requests
 from .resources import Resources
 from .shares import Shares
@@ -28,6 +30,8 @@ __all__ = (
     'Issues',
     'Measurements',
     'Memberships',
+    'Nodes',
+    'Reports',
     'Requests',
     'Resources',
     'Shares',
